#
# spec file for package rdiff-backup
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rdiff-backup
Version:        1.2.8
Release:        42.11
Summary:        Convenient and transparent local/remote incremental mirror/backup
License:        GPL-2.0+
Group:          Productivity/Archiving/Backup
Url:            http://www.nongnu.org/rdiff-backup/
Source0:        http://savannah.nongnu.org/download/rdiff-backup/%{name}-%{version}.tar.gz
Source1:        http://savannah.nongnu.org/download/rdiff-backup/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
Patch0:         rdiff-backup-fix-deprecations.diff
# well, upstream is apparently dead, but I found this patch on the upstream mailing list.
# PATCH-FEATURE-UPSTREAM rdiff-backup-1.2.8-sparsefiles.diff -- seife+obs@b1-systems.com
Patch1:         rdiff-backup-1.2.8-sparsefiles.diff
# in order not stumble on handle hardlinks, these two patches are necessary
# http://savannah.nongnu.org/bugs/?26848
# PATCH-FEATURE-UPSTREAM Hardlink.py.revised-patch compare.py.patch -- hpj@urpla.net
Patch2:         Hardlink.py.revised-patch
Patch3:         compare.py.patch
# don't take empty sessions into account, which has the potential of removing valid
# backups with --remove-older-than xB, while keeping empty/useless sessions instead
# patch is not upstream -- hpj@urpla.net
Patch4:         rdiff-backup-dont-pick-empty-sessions.diff
# the above patch is slightly broken, fix it by not using sparse code when writing
# compressed files
# PATCH-FIX-OPENSUSE rdiff-backup-1.2.8-sparse-no-seek-in-gzip.diff --seife+obs@b1-systems.com
Patch11:        rdiff-backup-1.2.8-sparse-no-seek-in-gzip.diff
# PATCH-FIX-UPSTREAM rdiff-backup-librsync-1.0.patch dimstar@opensuse.org -- Fix build with librsync 1.0.0
Patch12:        rdiff-backup-librsync-1.0.patch
BuildRequires:  python-devel
Recommends:     python-pylibacl
Recommends:     python-xattr
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%py_requires
%if 0%{?suse_version} > 1210
BuildRequires:  librsync-devel
%else
BuildRequires:  librsync
%endif

%description
rdiff-backup backs up one directory to another, possibly over a
network. The target directory ends up a copy of the source directory,
but extra reverse diffs are stored in a special subdirectory of that
target directory, so you can still recover files lost some time ago.
The idea is to combine the best features of a mirror and an incremental
backup. rdiff-backup also preserves subdirectories, hard links, dev
files, permissions, uid/gid ownership, and modification times. Also,
rdiff-backup can operate in a bandwidth efficient manner over a pipe,
like rsync. Thus you can use rdiff-backup and ssh to securely back a
hard drive up to a remote location, and only the differences will be
transmitted. Finally, rdiff-backup is easy to use and settings have
sensical defaults.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch11 -p1
%patch2
%patch3
%patch4 -p1
%patch12 -p1

%build
export CFLAGS="%{optflags}"
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root %{buildroot}
rm -rf %{buildroot}%{_datadir}/doc/rdiff-backup-%{version}

%files
%defattr(-, root, root)
%doc CHANGELOG COPYING FAQ.html examples.html README
%{_mandir}/*/*
%{_bindir}/*
%{py_sitedir}/rdiff_backup
%{py_sitedir}/*.egg-info

%changelog
* Mon Mar 16 2015 dimstar@opensuse.org
- Add rdiff-backup-librsync-1.0.patch: Fix build with
  librsync 1.0.0.
* Fri Mar 13 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add gpg signature
* Mon Jun 30 2014 seife+obs@b1-systems.com
- add rdiff-backup-1.2.8-sparse-no-seek-in-gzip.diff:
  the sparse code makes no sense in gzip compressed case and it
  triggers an IO error in gzip.py when trying to seek backwards
* Wed Apr 23 2014 hpj@urpla.net
- apply rdiff-backup-dont-pick-empty-sessions.diff:
  don't take empty sessions into account, which has the potential of
  removing valid backups with --remove-older-than xB, while keeping
  empty/useless sessions instead
* Fri Feb 14 2014 seife+obs@b1-systems.com
- add rdiff-backup-1.2.8-sparsefiles.diff to efficiently back up
  sparse files (found on rdiff-backup mailing list)
* Thu Nov 14 2013 hpj@urpla.net
- fix hardlink issue: http://savannah.nongnu.org/bugs/?26848
  - apply Joe Steeles patches to resolve it:
  * Hardlink.py.revised-patch
  * compare.py.patch
* Fri Mar 15 2013 hpj@urpla.net
- fix os.popen2 deprecation
- add recommends for python-xattr and python-pylibacl
* Mon Feb 20 2012 boris@steki.net
- fixed building on Factory as librsync is now split into lib and devel package
* Thu Sep  3 2009 poeml@suse.de
- update to 1.2.8
  New in v1.2.8:
  * Improve handling of incorrect permissions on backup repository during restore
    operation. Closes Ubuntu bug #329722. (Andrew Ferguson)
  * Don't crash on zlib errors. Closes Debian bug #518531. (Andrew Ferguson)
  * Make sticky bit warnings quieter while determining file system abilities.
    Closes Savannah bug #25788. (Andrew Ferguson)
  * Fix situation where destination file cannot be opened because of an access
    error. Thanks to Dean Cording for the bug report. (Andrew Ferguson)
  * Fix --compare-hash options on Windows. Thanks to Serge Zub for the fix.
  New in v1.2.7:
  * Don't crash when filesystem can't set ACL. Thanks to Matt Thompson for the bug
    report. (Andrew Ferguson)
  * Properly disable hardlinks by default on Windows.
  * Fix Python 2.2 compatibility. Closes Savannah bug #25529. (Andrew Ferguson)
  * Fix typo which caused failure when checking if another rdiff-backup process is
    running on Windows. Thanks to Ryan Hughes for the bug report. (Andrew Ferguson)
* Fri Feb 13 2009 puzel@suse.cz
- update to 1.2.6
  - too many changes to be listed here, please see
    /usr/share/doc/packages/rdiff-backup/CHANGELOG
  for details
* Tue Aug 26 2008 cthiel@suse.de
- update to version 1.2.1
  * Produce a new binary for Windows which includes the Python for Windows
    Extensions.
  * Disable hardlinks by default when backup source or restore destination
    is on Windows.
  * Properly catch KeyboardInterrupt on Python 2.5.
  * Don't crash if a CacheIndexable tries to clear a non-existent cache
    entry, since the entry must already be cleared.
* Mon Aug  4 2008 cthiel@suse.de
- update to version 1.2.0
  * This is the new stable branch of rdiff-backup, representing almost three
    years of development releases. From the previous development release, this
    release includes two fixes for Unicode issues. From the previous stable
    release, this release features a large number of new features, including
    SHA1 checksums, native Windows support, improved Mac OS X and Cygwin
    support, better filesystem support for HFS+, NFS, SSHFS, SMB, CIFS, AFS,
    NTFS, and FAT32, and better handling of unreadable or pathological file
    permissions. It also includes the previously separate
    'rdiff-backup-statistics' tool.
* Tue Jan  9 2007 cthiel@suse.de
- fix ICC warning:  warning #592: variable "return_val" is used before its
  value is set (#232824)
* Mon Jan  8 2007 cthiel@suse.de
- update to version 1.0.5
  * Fix a traceback due to an off-by-1 error in "--remove-older-than nB".
  * Fix a security violation when restoring from a remote repository.
  * --list-at-time, --list-increments, and --list-increment-sizes should now
    work from a read-only repository.
* Mon Oct  2 2006 cthiel@suse.de
- fix build on older distributions
* Thu Sep 21 2006 cthiel@suse.de
- fix build with python 2.5
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 cthiel@suse.de
- update to version 1.0.4
* Sat Nov 26 2005 cthiel@suse.de
- update to version 1.0.3
* Wed Oct 26 2005 cthiel@suse.de
- update to version 1.0.2
* Tue Sep 13 2005 cthiel@suse.de
- update to version 1.0.1
- specfile cleanup
* Wed Aug 17 2005 cthiel@suse.de
- update to version 1.0.0
* Sun Aug 14 2005 cthiel@suse.de
- use %%py_requires macro
* Tue May  3 2005 cthiel@suse.de
- use %%py_sitedir macro
* Fri Apr 15 2005 cthiel@suse.de
- initial creation of package (0.12.8)
